Pre Test
-----------------------------------------------------

Please try to solve each of the following problems to the best of your ability.
It is **OK** to not know the correct answers!  If you don't know the answer just select
option E (I don't know).

Problems
==============

.. timed:: dtimed1
   :timelimit: 20
   :noresult:
   :nofeedback:
   :nopause:

   .. selectquestion:: dclass-exp-pre-1
      :fromid: pretest_cond_with_funcs
      :points: 1

   .. selectquestion:: dclass-exp-pre-2
      :fromid: pretest-type-compare
      :points: 1

   .. selectquestion:: dclass-exp-pre-3-v2
      :fromid: pretest-mult-if
      :points: 1

   .. selectquestion:: dclass-exp-pre-4
      :fromid: pretest_complex_list_string
      :points: 1

   .. selectquestion:: dclass-exp-pre-5
      :fromid: pretest_sum_with_range
      :points: 1

   .. selectquestion:: dclass-exp-pre-6
      :fromid: pretest_string_abbrev
      :points: 1

   .. selectquestion:: dclass-exp-pre-7
      :fromid: pretest_sum_with_mod
      :points: 1

   .. selectquestion:: dclass-exp-pre-8
      :fromid: pretest-while-str-concat
      :points: 1

   .. selectquestion:: dclass-exp-pre-9
      :fromid: pretest-break-cont-str-cont
      :points: 1

   .. selectquestion:: dclass-exp-pre-10
      :fromid: pretest-string-slice-neg
      :points: 1

Feedback
==================================

.. shortanswer:: dp3-pre-sa

   Please provide feedback here. Please share any comments, problems, or suggestions.

Thank You 🤗
============================
🎉 We appreciate your participation in our study.
